@@ -399,8 +399,8 @@ char **splitman()
 
 	mpath = (char *) getenv("MANPATH");
 	if (mpath == NULL || *mpath == '\0') {
-		fprintf(stderr,"Warning: MANPATH not defined, using /usr/man\n");
-                mpath="/usr/man";
+		fprintf(stderr,"Warning: MANPATH not defined, using /usr/man:/usr/share/man\n");
+                mpath="/usr/man:/usr/share/man";
 	}
         /* make a copy that is static */
         cmpath = (char *)malloc(sizeof(char)*(strlen(mpath) + 2));
